@@ -29,9 +29,54 @@ from ...bluebase import (
     )
 from ...motv import Customer
 import requests
-import datetime
 import json
-import redis
+
+
+@api.route(
+    '/device/apilogin', methods=['POST']
+    )
+def motvApiLogin():
+    params = request.get_json()
+    data = {
+        "data": {
+            "login": params["login"],
+            "password": params["secret_code"],
+            },
+        "auth": TOKEN_SMS
+    }
+
+    data = json.dumps(data)
+    LOGS.logger.info(data)
+    response = requests.post(
+        '{uri}/devices/motv/apiLogin'.format(uri=SMS_URI),
+        data=data
+        )
+    if response.status_code == 200:
+        LOGS.logger.info(response.json())
+        code = response.json()["status"]
+        if code == 1:
+            response = {
+                "code": "044-05-{}".format(response.status_code),
+                "message": "Authentification OK :)",
+                "status": response.status_code,
+                "data": response.json()
+            }
+            LOGS.logger.info(response)
+            return success(service_code=SERVICE_CODE)
+        else:
+            response = {
+                    "code": "044-05-{}".format("4013"),
+                    "message": "Erreur d'authentification",
+                    "status": "4013",
+                }
+    else:
+        response = {
+                "code": "044-05-{}".format(response.status_code),
+                "message": "Erreur d'authentification",
+                "status": response.status_code,
+            }
+
+    return jsonify(response)
 
 
 @api.route('/sms/customer/all', methods=['GET'])
@@ -369,22 +414,12 @@ def ussdCustomerGetDataByLogin():
     if response.status_code == 200:
         response = response.json()
         if response["status"] == 1:
-            customer = Customer()
-            result = customer.getData(int(
-                response["response"]["device_motv_viewers_id"])
-                )
-            if result["status"] == 1:
-                customer_name = (
-                    result["response"]["viewers_firstname"] +
-                    " " +
-                    result["response"]["viewers_lastname"]
-                    )
-            else:
-                customer_name = response["response"]["device_motv_login"]
             response = {
                 "code": "044-05-200",
                 "message": {
-                    "customer_name": customer_name,
+                    "customer_name": (
+                        response["response"]["device_motv_login"]
+                        ),
                     "customer_id": (
                         response["response"]["device_motv_viewers_id"]
                         ),
@@ -664,11 +699,8 @@ def ussdCustomerSaveInvoice(login):
                     "moins"
                     )
                 LOGS.logger.info("Account new: "+json.dumps(account_new))
-                transaction_status = "Transaction en attente"
-                transaction_status = "Activation en attente"
                 if account_new["status"] == 200:
                     # Activation du produit
-                    transaction_status = "Transaction validée"
                     data = {
                         'session': '',
                         "operator": "bip",
@@ -685,7 +717,6 @@ def ussdCustomerSaveInvoice(login):
                     response = izytv_buy_recharge(data)
                     # Activation offre NON OK
                     if response["status"] != 200:
-                        activation_status = "Echec d'activation"
                         response = {
                             "code": "044-05-{}".format(
                                 response["status"]
@@ -703,7 +734,6 @@ def ussdCustomerSaveInvoice(login):
                         }
                         send_sms(data_sms)
                         # Roll back du solde du client
-                        transaction_status = "Roll back du solde"
                         account_new = update_balance(
                             params["caller_num"],
                             int(float(params["amount"])),
@@ -713,7 +743,6 @@ def ussdCustomerSaveInvoice(login):
                         LOGS.logger.info(account_new)
                     # Activation offre OK
                     elif response["status"] == 200:
-                        activation_status = "Activation reussie"
                         response = {
                             "code": "044-05-200",
                             "info": "Activation du produit",
@@ -728,7 +757,6 @@ def ussdCustomerSaveInvoice(login):
                             }
                         send_sms(data_sms)
                 else:
-                    transaction_status = "Echec de transaction"
                     message = MESSAGE[lg]["400"]
                     data_sms = {
                         "msisdn": params["caller_num"],
@@ -737,30 +765,6 @@ def ussdCustomerSaveInvoice(login):
                     send_sms(data_sms)
                     response = account_new
                     LOGS.logger.info(response)
-
-                # Enregistrement redis
-                re = redis.Redis(db=6)
-                mydate = datetime.datetime.today()
-                transaction_date = mydate.strftime("%Y-%m-%d %H:%M:%S")
-                redis_key = "request:payment:{}".format(request_id)
-                data_redis = {
-                    'operation_id': request_id,
-                    'info': activation_status,
-                    'partner_ref': request_id,
-                    'TransactionDate': transaction_date,
-                    'caller_num': params['caller_num'],
-                    'label': params['bundle_name'],
-                    'operator': 'ussd-bip',
-                    'status': transaction_status,
-                    'service_type': 'izytv',
-                    'offre_refnum': params['offer_id'],
-                    'amount': params['amount'],
-                    'client_refnum': customer['message']['client_refnum'],
-                    'other': params['device_name'],
-                    'device_id': login
-                    }
-                re.hmset(redis_key, data_redis)
-                LOGS.logger.info("Enregistrement redis OK")
             else:
                 message = MESSAGE[lg]["400"]
                 data_sms = {"msisdn": params["caller_num"], "message": message}
