@@ -19,7 +19,7 @@ class Customer(object):
             "auth": TOKEN_SMS
             }
         data = json.dumps(data)
-        # LOGS.logger.info("IzyTv get data by login:\n"+data)
+        LOGS.logger.info("IzyTv get data by login:\n"+data)
         response = requests.post(
             '{uri}/devices/motv/apiGetDataByLogin'.format(uri=SMS_URI),
             data=data
@@ -48,7 +48,7 @@ class Customer(object):
             "response": data,
             "status": status_code,
             }
-        # LOGS.logger.info(response)
+        LOGS.logger.info(response)
         return response
 
     def getData(self, viewers_id):
@@ -173,49 +173,6 @@ class Customer(object):
         LOGS.logger.info(response)
         return response
 
-    def all_customer(self):
-        data = {
-            "data": {
-                "reports_id": 2,
-                "page": None,
-                "page_limit": None
-                },
-            "auth": TOKEN_SMS
-            }
-        data = json.dumps(data)
-        LOGS.logger.info("IzyTv get all customer:\n"+data)
-        response = requests.post(
-            '{uri}/report/reportSelection'.format(uri=SMS_URI),
-            data=data
-            )
-        if response.status_code == 200:
-            status_code = 200
-            response = response.json()
-            if response["status"] == 1:
-                status_code = 1
-                info = "IzyTv get all customer successfully ;)"
-                data = response["response"]["rows"]
-            else:
-                status_code = response["status"]
-                info = "IzyTv get all customer {error}".format(
-                        error=(CODE_ERROR.get(str(response["status"]))).lower()
-                        )
-                data = {}
-        else:
-            status_code = response.status_code
-            info = "IzyTv get all customer failed!!!"
-            data = {}
-
-        response = {
-            "code": "044-05-{}".format(status_code),
-            "info": info,
-            "response": data,
-            "status": status_code,
-            }
-        LOGS.logger.info(response)
-        # return response
-        return data
-
     def register(self, data):
         LOGS.logger.info("IzyTv customer register:\n"+data)
         response = requests.post(
